        function getT(rr,cc){
       if(rr==7 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260629 a 00</strong> UTC HH+108 (rango:096-120)<br><strong>control +<br>EPS</strong>';}
       if(rr==7 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260629 a 00</strong> UTC HH+108 (rango:096-120)<br>grupo: <strong>1</strong> representante: <strong>33</strong> miembros: 27 <strong>control</strong><br>0,1,4,6,7,9,13,15,17,18,20,21,24,27,29,30,32,33,34,36,37,39,41,46,48,49,50';}
       if(rr==7 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260629 a 00</strong> UTC HH+108 (rango:096-120)<br>grupo: <strong>2</strong> representante: <strong>35</strong> miembros: 13 <br>2,5,10,12,22,23,25,31,35,43,44,45,47';}
       if(rr==7 && cc==3){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260629 a 00</strong> UTC HH+108 (rango:096-120)<br>grupo: <strong>3</strong> representante: <strong>14</strong> miembros: 11 <br>3,8,11,14,16,19,26,28,38,40,42';}
       if(rr==34 && cc==0){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 1.25 m</strong><br><br><strong>20260629 a 00</strong> UTC HH+108 (rango:096-120)<br><strong>control +<br>EPS</strong>';}
       if(rr==34 && cc==1){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 1.25 m</strong><br><br><strong>20260629 a 00</strong> UTC HH+108 (rango:096-120)<br>grupo: <strong>1</strong> representante: <strong>33</strong> miembros: 27 <strong>control</strong><br>0,1,4,6,7,9,13,15,17,18,20,21,24,27,29,30,32,33,34,36,37,39,41,46,48,49,50';}
       if(rr==34 && cc==2){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 1.25 m</strong><br><br><strong>20260629 a 00</strong> UTC HH+108 (rango:096-120)<br>grupo: <strong>2</strong> representante: <strong>35</strong> miembros: 13 <br>2,5,10,12,22,23,25,31,35,43,44,45,47';}
       if(rr==34 && cc==3){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 1.25 m</strong><br><br><strong>20260629 a 00</strong> UTC HH+108 (rango:096-120)<br>grupo: <strong>3</strong> representante: <strong>14</strong> miembros: 11 <br>3,8,11,14,16,19,26,28,38,40,42';}
       if(rr==35 && cc==0){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 2.5 m</strong><br><br><strong>20260629 a 00</strong> UTC HH+108 (rango:096-120)<br><strong>control +<br>EPS</strong>';}
       if(rr==35 && cc==1){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 2.5 m</strong><br><br><strong>20260629 a 00</strong> UTC HH+108 (rango:096-120)<br>grupo: <strong>1</strong> representante: <strong>33</strong> miembros: 27 <strong>control</strong><br>0,1,4,6,7,9,13,15,17,18,20,21,24,27,29,30,32,33,34,36,37,39,41,46,48,49,50';}
       if(rr==35 && cc==2){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 2.5 m</strong><br><br><strong>20260629 a 00</strong> UTC HH+108 (rango:096-120)<br>grupo: <strong>2</strong> representante: <strong>35</strong> miembros: 13 <br>2,5,10,12,22,23,25,31,35,43,44,45,47';}
       if(rr==35 && cc==3){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 2.5 m</strong><br><br><strong>20260629 a 00</strong> UTC HH+108 (rango:096-120)<br>grupo: <strong>3</strong> representante: <strong>14</strong> miembros: 11 <br>3,8,11,14,16,19,26,28,38,40,42';}
       if(rr==36 && cc==0){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 4 m</strong><br><br><strong>20260629 a 00</strong> UTC HH+108 (rango:096-120)<br><strong>control +<br>EPS</strong>';}
       if(rr==36 && cc==1){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 4 m</strong><br><br><strong>20260629 a 00</strong> UTC HH+108 (rango:096-120)<br>grupo: <strong>1</strong> representante: <strong>33</strong> miembros: 27 <strong>control</strong><br>0,1,4,6,7,9,13,15,17,18,20,21,24,27,29,30,32,33,34,36,37,39,41,46,48,49,50';}
       if(rr==36 && cc==2){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 4 m</strong><br><br><strong>20260629 a 00</strong> UTC HH+108 (rango:096-120)<br>grupo: <strong>2</strong> representante: <strong>35</strong> miembros: 13 <br>2,5,10,12,22,23,25,31,35,43,44,45,47';}
       if(rr==36 && cc==3){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 4 m</strong><br><br><strong>20260629 a 00</strong> UTC HH+108 (rango:096-120)<br>grupo: <strong>3</strong> representante: <strong>14</strong> miembros: 11 <br>3,8,11,14,16,19,26,28,38,40,42';}
       if(rr==37 && cc==0){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 6 m</strong><br><br><strong>20260629 a 00</strong> UTC HH+108 (rango:096-120)<br><strong>control +<br>EPS</strong>';}
       if(rr==37 && cc==1){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 6 m</strong><br><br><strong>20260629 a 00</strong> UTC HH+108 (rango:096-120)<br>grupo: <strong>1</strong> representante: <strong>33</strong> miembros: 27 <strong>control</strong><br>0,1,4,6,7,9,13,15,17,18,20,21,24,27,29,30,32,33,34,36,37,39,41,46,48,49,50';}
       if(rr==37 && cc==2){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 6 m</strong><br><br><strong>20260629 a 00</strong> UTC HH+108 (rango:096-120)<br>grupo: <strong>2</strong> representante: <strong>35</strong> miembros: 13 <br>2,5,10,12,22,23,25,31,35,43,44,45,47';}
       if(rr==37 && cc==3){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 6 m</strong><br><br><strong>20260629 a 00</strong> UTC HH+108 (rango:096-120)<br>grupo: <strong>3</strong> representante: <strong>14</strong> miembros: 11 <br>3,8,11,14,16,19,26,28,38,40,42';}
       if(rr==38 && cc==0){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 9 m</strong><br><br><strong>20260629 a 00</strong> UTC HH+108 (rango:096-120)<br><strong>control +<br>EPS</strong>';}
       if(rr==38 && cc==1){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 9 m</strong><br><br><strong>20260629 a 00</strong> UTC HH+108 (rango:096-120)<br>grupo: <strong>1</strong> representante: <strong>33</strong> miembros: 27 <strong>control</strong><br>0,1,4,6,7,9,13,15,17,18,20,21,24,27,29,30,32,33,34,36,37,39,41,46,48,49,50';}
       if(rr==38 && cc==2){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 9 m</strong><br><br><strong>20260629 a 00</strong> UTC HH+108 (rango:096-120)<br>grupo: <strong>2</strong> representante: <strong>35</strong> miembros: 13 <br>2,5,10,12,22,23,25,31,35,43,44,45,47';}
       if(rr==38 && cc==3){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 9 m</strong><br><br><strong>20260629 a 00</strong> UTC HH+108 (rango:096-120)<br>grupo: <strong>3</strong> representante: <strong>14</strong> miembros: 11 <br>3,8,11,14,16,19,26,28,38,40,42';}
       if(rr==39 && cc==0){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 14 m</strong><br><br><strong>20260629 a 00</strong> UTC HH+108 (rango:096-120)<br><strong>control +<br>EPS</strong>';}
       if(rr==39 && cc==1){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 14 m</strong><br><br><strong>20260629 a 00</strong> UTC HH+108 (rango:096-120)<br>grupo: <strong>1</strong> representante: <strong>33</strong> miembros: 27 <strong>control</strong><br>0,1,4,6,7,9,13,15,17,18,20,21,24,27,29,30,32,33,34,36,37,39,41,46,48,49,50';}
       if(rr==39 && cc==2){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 14 m</strong><br><br><strong>20260629 a 00</strong> UTC HH+108 (rango:096-120)<br>grupo: <strong>2</strong> representante: <strong>35</strong> miembros: 13 <br>2,5,10,12,22,23,25,31,35,43,44,45,47';}
       if(rr==39 && cc==3){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 14 m</strong><br><br><strong>20260629 a 00</strong> UTC HH+108 (rango:096-120)<br>grupo: <strong>3</strong> representante: <strong>14</strong> miembros: 11 <br>3,8,11,14,16,19,26,28,38,40,42';}
}
